/**
 * EasyBeans
 * Copyright (C) 2010 Bull S.A.S.
 * Contact: easybeans@ow2.org
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307
 * USA
 *
 * --------------------------------------------------------------------------
 * $Id: ChainedResolver.java 5461 2010-03-26 16:01:19Z sauthieg $
 * --------------------------------------------------------------------------
 */

package org.ow2.util.substitution.resolver;

import java.util.ArrayList;
import java.util.List;

import org.ow2.util.substitution.IPropertyResolver;

/**
 * Manage a List of IPropertyResolver. During resolution, the first non-null value returned by a resolver is used.
 * Order is the one of the resolvers List.
 * @author Guillaume Sauthier
 */
public class ChainedResolver implements IPropertyResolver {

    /**
     * Chain of resolvers.
     */
    private List<IPropertyResolver> resolvers;

    public ChainedResolver() {
        this.resolvers = new ArrayList<IPropertyResolver>();
    }

    public List<IPropertyResolver> getResolvers() {
        return resolvers;
    }

    /**
     * @param expression a property name
     * @return the value related to the expression, or null if not found.
     */
    public String resolve(final String expression) {

        // Return the first resolved value
        for (IPropertyResolver resolver : resolvers) {
            String resolved = resolver.resolve(expression);
            if (resolved != null) {
                return resolved;
            }
        }
        return null;
    }
}
